ASIMP :: Security Platform
ANSIBLE SYSTEM INTEGRITY MANAGEMENT PLATFORM // baselines & hardening
MODE:


About ASIMP

ASIMP is an automated framework built with Ansible to assess host compliance, configure OS parameters, secure SSH, and verify integrity.

System Core Playbooks Reference

Ansible >= 9.0.0 OpenSCAP: CIS L2 Lynis: Enabled debsums: Enabled

System Core Playbooks Reference

ASIMP’s execution workflow is controlled by two core playbooks depending on the target host scope.


🧭 Playbook Breakdown

1. play.yml

  • Scope: Designed for multi-node remote configurations.
  • Connection: Typically standard ssh with custom privilege escalation (become: true).

2. play-localhost.yml

  • Scope: Specialized for executing self-hardening on the local host controller node.
  • Connection: connection: local.

🔁 Hardening Phase Mapping

Both playbooks follow the Measure, Harden, Re-Measure workflow:

Playbook Start -> reporting-ASIMP (Pre-Scan) -> OS Hardening -> reporting-ASIMP (Post-Scan) -> End