Role lynis-ansible Reference
The lynis-ansible role automates Unix-based local systems security auditing using the Lynis engine.
⚙️ Key Variables & Defaults
| Variable | Default | Purpose |
|---|---|---|
lynis_profile |
default |
Scan profile name. |
lynis_tests_to_skip |
[] |
List of tests to skip. |
lynis_extra_parameters |
"" |
Extra arguments for the lynis audit system command. |
💾 Extracted Metrics
- Hardening Index: An overall numerical representation of how secure the system configurations are (0 to 100).
- Warnings and Suggestions: Logged under
/var/log/lynis-report.datfor post-hardening review.